@@ -13,7 +13,7 @@ from tqdm import tqdm
 
 from dql.client import Client
 from dql.data_storage import AbstractDataStorage
-from dql.dataset import DatasetRecord
+from dql.dataset import DatasetRecord, DatasetRow
 from dql.listing import Listing
 from dql.node import NodeWithPath
 from dql.storage import Status, Storage
@@ -511,7 +511,7 @@ class Catalog:
         self,
         dataset_name: str,
         new_dataset_name: Optional[str] = None,
-        version: Optional[str] = None,
+        version: Optional[int] = None,
         description: Optional[str] = None,
         labels: Optional[List[str]] = None,
     ):
@@ -523,7 +523,7 @@ class Catalog:
             raise RuntimeError(f"Dataset is already registered: {dataset_name}")
 
         update_data = {
-            "version": version or "1",
+            "version": version or 1,
             "shadow": False,
             "description": description,
             "labels": labels,
@@ -537,6 +537,9 @@ class Catalog:
     def ls_datasets(self, shadow_only=None) -> Iterable[DatasetRecord]:
         yield from self.data_storage.get_datasets(shadow_only=shadow_only)
 
+    def ls_dataset_rows(self, name: str, limit=None) -> Iterable[DatasetRow]:
+        yield from self.data_storage.get_dataset_rows(name, limit=limit)
+
     def remove_dataset(self, name: str):
         self.data_storage.remove_dataset(name)
 
