@@ -235,6 +235,11 @@ def get_parser() -> ArgumentParser:
         help="List only shadow datasets, or only registered datasets",
     )
 
+    ls_dataset_rows_parser = subp.add_parser(
+        "ls-dataset-rows", parents=[parent_parser], help="List dataset rows"
+    )
+    ls_dataset_rows_parser.add_argument("name", type=str, help="Dataset name")
+
     rm_dataset_parser = subp.add_parser(
         "rm-dataset", parents=[parent_parser], help="Removes dataset"
     )
@@ -580,6 +585,12 @@ def ls_datasets(shadow_only=None):
             print(d.name)
 
 
+def ls_dataset_rows(name: str):
+    for row in Catalog(SQLiteDataStorage()).ls_dataset_rows(name):
+        entry = row.name + ("/" if row.dir_type else "")  # type: ignore[attr-defined]
+        print(format_ls_entry(entry))
+
+
 def rm_dataset(name: str):
     Catalog(SQLiteDataStorage()).remove_dataset(name)
 
@@ -694,6 +705,8 @@ def main(argv: Optional[List[str]] = None) -> int:  # noqa: C901
             )
         elif args.command == "ls-datasets":
             ls_datasets(args.shadow)
+        elif args.command == "ls-dataset-rows":
+            ls_dataset_rows(args.name)
         elif args.command == "rm-dataset":
             rm_dataset(args.name)
         elif args.command == "du":
