@@ -1,9 +1,11 @@
 import asyncio
 import multiprocessing
+import posixpath
 from abc import abstractmethod
 from datetime import datetime
 from typing import TYPE_CHECKING, ClassVar, Iterator, Tuple, Type
 
+from botocore.exceptions import ClientError
 from fsspec.asyn import get_loop
 from tqdm import tqdm
 
@@ -30,7 +32,9 @@ class FSSpecClient(Client):
     @classmethod
     def create_fs(cls, **kwargs) -> "AbstractFileSystem":
         kwargs.setdefault("version_aware", True)
-        return cls.FS_CLASS(**kwargs)
+        fs = cls.FS_CLASS(**kwargs)
+        fs.invalidate_cache()
+        return fs
 
     @classmethod
     def ls_buckets(cls, **kwargs) -> Iterator[Bucket]:
@@ -50,6 +54,14 @@ class FSSpecClient(Client):
     def uri(self):
         return f"{self.PREFIX}{self.name}"
 
+    @classmethod
+    def split_url(cls, url: str) -> Tuple[str, str]:
+        fill_path = url[len(cls.PREFIX) :]
+        path_split = fill_path.split("/", 1)
+        bucket = path_split[0]
+        path = path_split[1] if len(path_split) > 1 else ""
+        return bucket, path
+
     @classmethod
     def _parse_url(
         cls,
@@ -62,21 +74,29 @@ class FSSpecClient(Client):
         E.g if the source is s3://bucket_name/dir1/dir2/dir3 this method would
         return Storage object of bucket_name and a path which is dir1/dir2/dir3
         """
-        fill_path = source[len(cls.PREFIX) :]
-        path_split = fill_path.split("/", 1)
-        storage = path_split[0]
-        path = path_split[1] if len(path_split) > 1 else ""
+        storage, path = cls.split_url(source)
         client = cls(storage, **kwargs)
         return client, path
 
-    async def fetch(self, listing):
+    async def fetch(self, listing, start_prefix=""):
         data_storage = listing.data_storage.clone()
-        root_id = await listing.insert_root(data_storage=data_storage)
+        if start_prefix:
+            start_prefix = start_prefix.rstrip("/")
+            start_id = await listing.insert_dir(
+                None,
+                posixpath.basename(start_prefix),
+                datetime.max,
+                start_prefix,
+                data_storage=data_storage,
+            )
+        else:
+            start_id = await listing.insert_root(data_storage=data_storage)
+
         progress_bar = tqdm(desc=f"Listing {self.uri}", unit=" objects")
         loop = get_loop()
 
         queue = asyncio.Queue()
-        queue.put_nowait((root_id, ""))
+        queue.put_nowait((start_id, start_prefix))
 
         async def worker(queue, data_storage):
             while True:
@@ -95,18 +115,24 @@ class FSSpecClient(Client):
                 finally:
                     queue.task_done()
 
-        workers = []
-        for _ in range(FETCH_WORKERS):
-            workers.append(loop.create_task(worker(queue, data_storage)))
+        try:
+            workers = []
+            for _ in range(FETCH_WORKERS):
+                workers.append(loop.create_task(worker(queue, data_storage)))
 
-        await queue.join()
-        for worker in workers:
-            worker.cancel()
-        await asyncio.gather(*workers)
+            await queue.join()
+            for worker in workers:
+                worker.cancel()
+            await asyncio.gather(*workers)
+        except ClientError as exc:
+            raise RuntimeError(
+                exc.response.get("Error", {}).get("Message") or exc
+            ) from exc
+        finally:
+            # This ensures the progress bar is closed before any exceptions are raised
+            progress_bar.close()
 
-    async def _fetch_dir(
-        self, dir_id, prefix, delimiter, pbar, listing, data_storage
-    ):
+    async def _fetch_dir(self, dir_id, prefix, delimiter, pbar, listing, data_storage):
         path = f"{self.name}/{prefix}"
         # pylint:disable-next=protected-access
         infos = await self.fs._ls(path, detail=True, versions=True)
@@ -126,9 +152,7 @@ class FSSpecClient(Client):
                 )
                 subdirs.add((new_dir_id, subprefix))
             else:
-                files.append(
-                    self._dict_from_info(info, dir_id, delimiter, subprefix)
-                )
+                files.append(self._dict_from_info(info, dir_id, delimiter, subprefix))
         if files:
             await data_storage.insert_entries(files)
         pbar.update(len(subdirs) + len(files))
@@ -148,6 +172,7 @@ class FSSpecClient(Client):
         total_size=None,
         cls=NodesFetcher,
         pb_descr="Download",
+        shared_progress_bar=None,
     ):
         fetcher = cls(
             self,
@@ -160,7 +185,7 @@ class FSSpecClient(Client):
         chunk_gen = NodeChunk(nodes)
         target_name = self.visual_file_name(file_path)
         pb_descr = f"{pb_descr} {target_name}"
-        return fetcher.run(chunk_gen, pb_descr, total_size)
+        return fetcher.run(chunk_gen, pb_descr, total_size, shared_progress_bar)
 
     def iter_object_chunks(self, bucket, path, version=None):
         with self.fs.open(f"{bucket}/{path}", version_id=version) as f:
