@@ -1,6 +1,6 @@
 from base64 import b64decode
 
-from gcsfs import GCSFileSystem
+from dql.vendored.gcsfs import GCSFileSystem
 
 from .fsspec import FSSpecClient
 
@@ -19,11 +19,16 @@ class GCSClient(FSSpecClient):
 
     @classmethod
     def _dict_from_info(cls, v, parent_id, delimiter, path):
+        name = v.get("name", "").split(delimiter)[-1]
+        if "generation" in v:
+            gen = f"#{v['generation']}"
+            if name.endswith(gen):
+                name = name[: -len(gen)]
         return {
             "is_dir": False,
             "parent_id": parent_id,
             "path": path,
-            "name": v.get("name", "").split(delimiter)[-1],
+            "name": name,
             # 'expires': expires,
             "checksum": b64decode(v.get("md5Hash", "")).hex(),
             "etag": v.get("etag", ""),
