@@ -1,7 +1,7 @@
 from datetime import datetime
 from typing import cast
 
-from dql.vendored.s3fs import S3FileSystem  # type: ignore[attr-defined]
+from s3fs import S3FileSystem
 
 from .fsspec import FSSpecClient
 
@@ -33,17 +33,13 @@ class ClientS3(FSSpecClient):
 
         return cast(S3FileSystem, super().create_fs(**kwargs))
 
-    async def _fetch_dir(
-        self, dir_id, prefix, delimiter, pbar, listing, data_storage
-    ):
+    async def _fetch_dir(self, dir_id, prefix, delimiter, pbar, listing, data_storage):
         if prefix:
             prefix = prefix.lstrip("/") + "/"
         files = []
         subdirs = set()
         # pylint:disable-next=protected-access
-        async for info in self.fs._iterdir(
-            self.name, prefix=prefix, versions=True
-        ):
+        async for info in self.fs._iterdir(self.name, prefix=prefix, versions=True):
             full_path = info["name"]
             _, subprefix, _ = self.fs.split_path(info["name"])
             if info["type"] == "directory":
@@ -57,9 +53,7 @@ class ClientS3(FSSpecClient):
                 )
                 subdirs.add((new_dir_id, subprefix))
             else:
-                files.append(
-                    self._dict_from_info(info, dir_id, delimiter, subprefix)
-                )
+                files.append(self._dict_from_info(info, dir_id, delimiter, subprefix))
                 if len(files) >= FETCH_CHUNKSIZE:
                     await data_storage.insert_entries(files)
                     pbar.update(len(files))
