@@ -17,7 +17,7 @@ from dql.node import AnyNode, Node, NodeWithPath
 from dql.storage import Storage
 
 if TYPE_CHECKING:
-    from dql.dataset import DatasetRecord
+    from dql.dataset import DatasetRecord, DatasetRow
 
 DB_FILE_NAME = "db"
 
@@ -52,6 +52,12 @@ class AbstractDataStorage(ABC):
     def get_dataset(self, name: str) -> Optional["DatasetRecord"]:
         """Finds dataset by name"""
 
+    @abstractmethod
+    def get_dataset_rows(
+        self, name: str, limit: Optional[int] = None
+    ) -> Iterable["DatasetRow"]:
+        """Gets dataset rows"""
+
     @abstractmethod
     def remove_dataset(self, name: str) -> None:
         """Removes dataset by name and it's corresponding entries"""
