@@ -9,7 +9,7 @@ from time import sleep
 from typing import Any, Dict, Iterable, Iterator, List, Optional, Tuple, Union
 
 from dql.data_storage.abstract import AbstractDataStorage
-from dql.dataset import DatasetRecord
+from dql.dataset import DatasetRecord, DatasetRow
 from dql.error import DQLError
 from dql.node import AnyNode, DirType, Node, NodeWithPath
 from dql.storage import Status as StorageStatus
@@ -164,7 +164,7 @@ class SQLiteDataStorage(AbstractDataStorage):
                 id              INTEGER PRIMARY KEY,
                 name            TEXT NOT NULL UNIQUE,
                 description     TEXT,
-                version         TEXT,
+                version         INTEGER,
                 labels          JSON DEFAULT('[]'),
                 shadow          BOOL NOT NULL
             );
@@ -257,6 +257,7 @@ class SQLiteDataStorage(AbstractDataStorage):
 
     @property
     def partials(self):
+        assert self.table_name, "Should choose uri/table_name first"
         return Query(self.db, PartialSchema(), f"{self.table_name}_indexed")
 
     def _get_nodes_by_glob_path_pattern(
@@ -365,6 +366,24 @@ class SQLiteDataStorage(AbstractDataStorage):
         ).fetchall():
             yield DatasetRecord.parse(*row)
 
+    def get_dataset_rows(self, name: str, limit=20) -> Iterable[DatasetRow]:
+        # TODO implement listing specific versions
+        dataset = self.get_dataset(name)
+        assert dataset
+        dataset_table_name = self._dataset_table_name(dataset.id)
+
+        limit_q = ""
+        args = []
+        if limit:
+            limit_q = "LIMIT ?"
+            args.append(limit)
+
+        for row in self.db.execute(
+            f"""SELECT * FROM {dataset_table_name} {limit_q}""",
+            args,
+        ).fetchall():
+            yield DatasetRow(*row)
+
     def create_shadow_dataset(self, name: str) -> None:
         """Creates new shadow dataset if it doesn't exist yet"""
         with self.db:
@@ -387,8 +406,6 @@ class SQLiteDataStorage(AbstractDataStorage):
                 CREATE TABLE IF NOT EXISTS {table_name}
                 (
                     id              INTEGER PRIMARY KEY,
-                    source          TEXT NOT NULL,
-                    path_str        TEXT,
                     dir_type        INTEGER,
                     parent_id       INTEGER,
                     name            TEXT NOT NULL,
@@ -400,7 +417,9 @@ class SQLiteDataStorage(AbstractDataStorage):
                     size            BIGINT NOT NULL,
                     owner_name      TEXT,
                     owner_id        TEXT,
-                    anno            JSON
+                    path_str        TEXT,
+                    anno            JSON,
+                    source          TEXT NOT NULL
                 );
                 """
             )
@@ -414,12 +433,12 @@ class SQLiteDataStorage(AbstractDataStorage):
         source_table_name = self._listing_table_name(uri)
         dataset_table_name = self._dataset_table_name(dataset.id)
 
+        self.table_name = source_table_name  # needed for parent node and .nodes
         if recursive:
             if not path.endswith("*"):
                 path = path.rstrip("/") + "/*"  # glob filter must end with /*
             nodes = self.nodes.where(path_str__glob=path, type="file")
         else:
-            self.table_name = source_table_name  # needed for parent node
             parent = self.get_node_by_path(path.lstrip("/").rstrip("/*"))
             nodes = self.nodes.where(parent_id=parent.id, type="file")
 
@@ -536,7 +555,7 @@ class SQLiteDataStorage(AbstractDataStorage):
 
     @retry_sqlite_locks
     def create_storage_if_not_registered(self, uri: str) -> None:
-        self.storages.insert({"uri": uri, "status": StorageStatus.CREATED}, upsert=True)
+        self.storages.insert({"uri": uri, "status": StorageStatus.CREATED}, silent=True)
 
     def register_storage_for_indexing(
         self,
@@ -593,9 +612,11 @@ class SQLiteDataStorage(AbstractDataStorage):
         """
         Deletes the provided and any subdir indexed prefixes and nodes
         """
+        bare_prefix = prefix.rstrip("/")
         dir_prefix = posixpath.join(prefix, "")
         self.partials.where(path_str__startswith=dir_prefix).delete()
-        self.nodes.where(path_str__startswith=prefix).delete()
+        self.nodes.where(path_str__startswith=dir_prefix).delete()
+        self.nodes.where(path_str=bare_prefix).delete()
 
     def check_partial_index_valid(self, prefix: str):
         # This SQL statement finds all matching path_str entries that are
@@ -622,6 +643,9 @@ class SQLiteDataStorage(AbstractDataStorage):
         end_time: Optional[datetime] = None,
         prefix: str = "",
     ) -> None:
+        if status == StorageStatus.PARTIAL and not prefix:
+            raise AssertionError("Partial indexing requires a prefix")
+
         if end_time is None:
             end_time = datetime.now(timezone.utc)
         expires = Storage.get_expiration_time(end_time, ttl)
@@ -635,13 +659,14 @@ class SQLiteDataStorage(AbstractDataStorage):
                 status=status,
             )
 
+            if not self.table_name:
+                # This only occurs in tests
+                return
+
             if status in {StorageStatus.COMPLETE, StorageStatus.FAILED}:
                 # Delete remaining partial index paths
                 self.partials.delete()
             elif status == StorageStatus.PARTIAL:
-                if not prefix:
-                    raise RuntimeError("Partial indexing requires a prefix!")
-
                 dirprefix = posixpath.join(prefix, "")
                 row = {"path_str": dirprefix, "timestamp": end_time, "expires": expires}
                 self.partials.insert(row)
