@@ -52,10 +52,7 @@ def clean_environment(
 
 @pytest.fixture
 def data_storage():
-    uri = "s3://somebucket"
-    _data_storage = SQLiteDataStorage(db_file=":memory:").clone(uri)
-    _data_storage.uri = uri
-    _data_storage.init_db()
+    _data_storage = SQLiteDataStorage(db_file=":memory:")
     yield _data_storage
 
     # Check that the DB isn't locked after the test
@@ -189,7 +186,6 @@ def cloud_test_catalog(
     tmpfile_dir = tmp_path / ".dql" / "tmp"
     tmpfile_dir.mkdir()
 
-    data_storage = data_storage.clone(str(cloud_server.src).rstrip("/"))
     catalog = Catalog(data_storage, cache_dir=str(cache_dir), tmp_dir=str(tmpfile_dir))
 
     return CloudTestCatalog(
