@@ -9,6 +9,42 @@ from dql.catalog import parse_dql_file
 from dql.utils import remove_readonly
 
 
+@pytest.fixture
+def dogs_shadow_dataset(cloud_test_catalog):
+    shadow_dataset_name = uuid.uuid4().hex
+    src = cloud_test_catalog.src
+    catalog = cloud_test_catalog.catalog
+
+    # list source to have it in db as source for dataset
+    list(
+        catalog.ls(
+            [str(src)],
+            client_config=cloud_test_catalog.client_config,
+        )
+    )
+
+    catalog.upsert_shadow_dataset(
+        shadow_dataset_name,
+        [str(src / "dogs" / "*")],
+        client_config=cloud_test_catalog.client_config,
+        recursive=True,
+    )
+
+    return catalog.data_storage.get_dataset(shadow_dataset_name)
+
+
+@pytest.fixture
+def dogs_registered_dataset(cloud_test_catalog, dogs_shadow_dataset):
+    catalog = cloud_test_catalog.catalog
+    catalog.register(
+        dogs_shadow_dataset.name,
+        description="dogs dataset",
+        labels=["dogs", "dataset"],
+    )
+
+    return catalog.data_storage.get_dataset(dogs_shadow_dataset.name)
+
+
 def test_find(cloud_test_catalog):
     src = cloud_test_catalog.src
     catalog = cloud_test_catalog.catalog
@@ -839,37 +875,20 @@ def test_upserting_shadow_dataset(cloud_test_catalog):
     assert data
 
 
-def test_registering_dataset(cloud_test_catalog):
-    shadow_dataset_name = uuid.uuid4().hex
-    src = cloud_test_catalog.src
+def test_registering_dataset(cloud_test_catalog, dogs_shadow_dataset):
     catalog = cloud_test_catalog.catalog
 
-    # list source to have it in db as source for dataset
-    list(
-        catalog.ls(
-            [str(src)],
-            client_config=cloud_test_catalog.client_config,
-        )
-    )
-
-    catalog.upsert_shadow_dataset(
-        shadow_dataset_name,
-        [str(src / "dogs" / "*")],
-        client_config=cloud_test_catalog.client_config,
-        recursive=True,
-    )
-
     catalog.register(
-        shadow_dataset_name,
+        dogs_shadow_dataset.name,
         description="dogs dataset",
         labels=["dogs", "dataset"],
     )
 
-    dataset = catalog.data_storage.get_dataset(shadow_dataset_name)
+    dataset = catalog.data_storage.get_dataset(dogs_shadow_dataset.name)
     dataset_table_name = catalog.data_storage._dataset_table_name(dataset.id)
-    assert dataset.name == shadow_dataset_name
+    assert dataset.name == dogs_shadow_dataset.name
     assert dataset.description == "dogs dataset"
-    assert dataset.version == "1"
+    assert dataset.version == 1
     assert dataset.labels == ["dogs", "dataset"]
     assert dataset.shadow is False
     data = catalog.data_storage.db.execute(
@@ -878,29 +897,12 @@ def test_registering_dataset(cloud_test_catalog):
     assert data
 
 
-def test_registering_dataset_with_new_name(cloud_test_catalog):
-    shadow_dataset_name = uuid.uuid4().hex
+def test_registering_dataset_with_new_name(cloud_test_catalog, dogs_shadow_dataset):
     new_dataset_name = uuid.uuid4().hex
-    src = cloud_test_catalog.src
     catalog = cloud_test_catalog.catalog
 
-    # list source to have it in db as source for dataset
-    list(
-        catalog.ls(
-            [str(src)],
-            client_config=cloud_test_catalog.client_config,
-        )
-    )
-
-    catalog.upsert_shadow_dataset(
-        shadow_dataset_name,
-        [str(src / "dogs" / "*")],
-        client_config=cloud_test_catalog.client_config,
-        recursive=True,
-    )
-
     catalog.register(
-        shadow_dataset_name,
+        dogs_shadow_dataset.name,
         new_dataset_name=new_dataset_name,
         description="dogs dataset",
         labels=["dogs", "dataset"],
@@ -915,67 +917,35 @@ def test_registering_dataset_with_new_name(cloud_test_catalog):
     assert data
 
 
-def test_registering_dataset_with_custom_version(cloud_test_catalog):
-    shadow_dataset_name = uuid.uuid4().hex
-    src = cloud_test_catalog.src
+def test_registering_dataset_with_custom_version(
+    cloud_test_catalog, dogs_shadow_dataset
+):
     catalog = cloud_test_catalog.catalog
 
-    # list source to have it in db as source for dataset
-    list(
-        catalog.ls(
-            [str(src)],
-            client_config=cloud_test_catalog.client_config,
-        )
-    )
-
-    catalog.upsert_shadow_dataset(
-        shadow_dataset_name,
-        [str(src / "dogs" / "*")],
-        client_config=cloud_test_catalog.client_config,
-        recursive=True,
-    )
-
     catalog.register(
-        shadow_dataset_name,
-        version="0.0.1",
+        dogs_shadow_dataset.name,
+        version=5,
         description="dogs dataset",
         labels=["dogs", "dataset"],
     )
 
-    dataset = catalog.data_storage.get_dataset(shadow_dataset_name)
-    assert dataset.version == "0.0.1"
+    dataset = catalog.data_storage.get_dataset(dogs_shadow_dataset.name)
+    assert dataset.version == 5
 
 
-def test_removing_dataset(cloud_test_catalog):
-    shadow_dataset_name = uuid.uuid4().hex
-    src = cloud_test_catalog.src
+def test_removing_dataset(cloud_test_catalog, dogs_shadow_dataset):
     catalog = cloud_test_catalog.catalog
 
-    # list source to have it in db as source for dataset
-    list(
-        catalog.ls(
-            [str(src)],
-            client_config=cloud_test_catalog.client_config,
-        )
+    dataset_table_name = catalog.data_storage._dataset_table_name(
+        dogs_shadow_dataset.id
     )
-
-    catalog.upsert_shadow_dataset(
-        shadow_dataset_name,
-        [str(src / "dogs" / "*")],
-        client_config=cloud_test_catalog.client_config,
-        recursive=True,
-    )
-
-    dataset = catalog.data_storage.get_dataset(shadow_dataset_name)
-    assert dataset
-    dataset_table_name = catalog.data_storage._dataset_table_name(dataset.id)
     data = catalog.data_storage.db.execute(
         f"select * from {dataset_table_name}"
     ).fetchall()
     assert data
 
-    catalog.remove_dataset(shadow_dataset_name)
-    dataset = catalog.data_storage.get_dataset(shadow_dataset_name)
+    catalog.remove_dataset(dogs_shadow_dataset.name)
+    dataset = catalog.data_storage.get_dataset(dogs_shadow_dataset.name)
     assert dataset is None
     with pytest.raises(sqlite3.OperationalError):
         catalog.data_storage.db.execute(
@@ -983,43 +953,30 @@ def test_removing_dataset(cloud_test_catalog):
         ).fetchall()
 
 
-def test_edit_dataset(cloud_test_catalog):
-    shadow_dataset_name = uuid.uuid4().hex
+def test_edit_dataset(cloud_test_catalog, dogs_registered_dataset):
     dataset_new_name = uuid.uuid4().hex
-    src = cloud_test_catalog.src
     catalog = cloud_test_catalog.catalog
 
-    # list source to have it in db as source for dataset
-    list(
-        catalog.ls(
-            [str(src)],
-            client_config=cloud_test_catalog.client_config,
-        )
-    )
-
-    catalog.upsert_shadow_dataset(
-        shadow_dataset_name,
-        [str(src / "dogs" / "*")],
-        client_config=cloud_test_catalog.client_config,
-        recursive=True,
-    )
-
-    catalog.register(
-        shadow_dataset_name,
-        version="0.0.1",
-        description="dogs dataset",
-        labels=["dogs", "dataset"],
-    )
-
     catalog.edit_dataset(
-        shadow_dataset_name,
+        dogs_registered_dataset.name,
         new_name=dataset_new_name,
         description="new description",
         labels=["cats", "birds"],
     )
 
     dataset = catalog.data_storage.get_dataset(dataset_new_name)
-    assert dataset.version == "0.0.1"
+    assert dataset.version == 1
     assert dataset.name == dataset_new_name
     assert dataset.description == "new description"
     assert dataset.labels == ["cats", "birds"]
+
+
+def test_ls_dataset_rows(cloud_test_catalog, dogs_registered_dataset):
+    catalog = cloud_test_catalog.catalog
+
+    assert [r.name for r in catalog.ls_dataset_rows(dogs_registered_dataset.name)] == [
+        "dog1",
+        "dog2",
+        "dog3",
+        "dog4",
+    ]
