@@ -82,6 +82,7 @@ def test_ls_partial_indexing(cloud_test_catalog, capsys):
     data_storage = cloud_test_catalog.catalog.data_storage
     data_storage.storages.delete()
     src = str(cloud_test_catalog.src).rstrip("/")
+    src_storage = data_storage.clone(src)
 
     ls(
         [f"{src}/dogs/others/"],
@@ -92,7 +93,7 @@ def test_ls_partial_indexing(cloud_test_catalog, capsys):
     # and to avoid any flaky tests due to multithreading generating output out of order
     sleep(0.05)
     captured = capsys.readouterr()
-    assert data_storage.partials.col("path_str") == ["dogs/others/"]
+    assert src_storage.partials.col("path_str") == ["dogs/others/"]
     assert "Listing" in captured.err
     assert "dog4" in captured.out
 
@@ -103,7 +104,7 @@ def test_ls_partial_indexing(cloud_test_catalog, capsys):
     )
     sleep(0.05)
     captured = capsys.readouterr()
-    assert data_storage.partials.col("path_str") == ["cats/", "dogs/others/"]
+    assert src_storage.partials.col("path_str") == ["cats/", "dogs/others/"]
     assert "Listing" in captured.err
     assert "cat1\ncat2" in captured.out
 
@@ -114,7 +115,7 @@ def test_ls_partial_indexing(cloud_test_catalog, capsys):
     )
     sleep(0.05)
     captured = capsys.readouterr()
-    assert data_storage.partials.col("path_str") == ["cats/", "dogs/"]
+    assert src_storage.partials.col("path_str") == ["cats/", "dogs/"]
     assert "Listing" in captured.err
     assert "others/\ndog1\ndog2\ndog3" in captured.out
 
@@ -125,7 +126,7 @@ def test_ls_partial_indexing(cloud_test_catalog, capsys):
     )
     sleep(0.05)
     captured = capsys.readouterr()
-    assert data_storage.partials.col("path_str") == ["cats/", "dogs/"]
+    assert src_storage.partials.col("path_str") == ["cats/", "dogs/"]
     assert "Listing" not in captured.err
     assert "cat1\ncat2" in captured.out
 
@@ -136,7 +137,7 @@ def test_ls_partial_indexing(cloud_test_catalog, capsys):
     )
     sleep(0.05)
     captured = capsys.readouterr()
-    assert data_storage.partials.col("path_str") == []
+    assert src_storage.partials.col("path_str") == []
     assert "Listing" in captured.err
     assert "cats/\ndogs/\ndescription" in captured.out
 
