@@ -190,18 +190,14 @@ def test_confident_cat(con):
 
 def test_func_contains_string_match(con):
     query = "contains(`foobar`, `foo`)"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
     assert len(res) == 3
 
 
 def test_func_contains_string_missmatch(con):
     query = "contains(`foobar`, `omg`)"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
     assert len(res) == 0
 
@@ -215,9 +211,7 @@ def test_func_contains_string_error(con):
 
 def test_func_contains_field(con):
     query = "contains(class, `at`)"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
 
     assert len(res) == 2
@@ -226,9 +220,7 @@ def test_func_contains_field(con):
 
 def test_func_contains_field_subexpression(con):
     query = "contains(inference.class, `at`)"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
 
     assert len(res) == 1
@@ -237,9 +229,7 @@ def test_func_contains_field_subexpression(con):
 
 def test_subexpression_equals_to_string(con):
     query = "inference.class == `dog`"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
 
     assert len(res) == 1
@@ -248,9 +238,7 @@ def test_subexpression_equals_to_string(con):
 
 def test_subexpression_equals_to_subexpression(con):
     query = "class == inference.class"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
 
     assert len(res) == 1
@@ -259,9 +247,7 @@ def test_subexpression_equals_to_subexpression(con):
 
 def test_larger_than_a_number(con):
     query = "num_annotators > `6`"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
 
     assert len(res) == 1
@@ -270,36 +256,28 @@ def test_larger_than_a_number(con):
 
 def test_not_sql_number_larger(con):
     query = "`872` > `539`"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
     assert len(res) == 3
 
 
 def test_not_sql_number_equal(con):
     query = "`4546` == `4546`"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
     assert len(res) == 3
 
 
 def test_not_sql_number_larger_error(con):
     query = "`34` > `834`"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
     assert len(res) == 0
 
 
 def test_func_contains_array(con):
     query = "detections[1].LabelName == `/m/0bt9lr`"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
 
     assert len(res) == 1
@@ -308,9 +286,7 @@ def test_func_contains_array(con):
 
 def test_func_contains_array_error(con):
     query = "detections[1].LabelName == `/m/0b_rs`"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
     assert len(res) == 0
 
@@ -325,9 +301,7 @@ def test_jmes_contains_with_projection(con):
     # FROM meta
 
     query = "contains(detections[*].LabelName, `/m/0bt9lr`)"
-    cursor = Transpiler.execute_query(
-        con, query, "meta", "data", ["name", "data"]
-    )
+    cursor = Transpiler.execute_query(con, query, "meta", "data", ["name", "data"])
     res = cursor.fetchall()
 
     assert len(res) == 1
