@@ -50,7 +50,7 @@ def test_adding_storage(data_storage):
 
 
 def test_storage_status(data_storage):
-    uri = data_storage.uri
+    uri = "s3://somebucket"
 
     data_storage.create_storage_if_not_registered(uri)
     storage = data_storage.get_storage(uri)
